@@ -1,7 +1,9 @@
 import json
 import logging
 import os
+from typing import Callable, Dict, List
 
+import pandas
 from fastapi.encoders import jsonable_encoder
 
 from .accuracy import calibration, largest_errors, metrics
@@ -9,46 +11,48 @@ from .dependence import partialdep
 from .expectations import condexp
 from .importance import varimp
 from .shap import ShapExplainer
-from .utils import create_description, df_to_dict
+from .utils import create_description, df_to_dict, input_schema_to_pandas
 
 BASE_RESULTS_PATH = os.environ.get("BASE_RESULTS_PATH", "results")
 
 
-def mkdir(endpoint, spec_path=""):
-    folder = os.path.join(BASE_RESULTS_PATH, endpoint.series_func.__name__, spec_path)
+def mkdir(endpoint_name, spec_path=""):
+    folder = os.path.join(BASE_RESULTS_PATH, endpoint_name, spec_path)
     if not os.path.exists(folder):
         os.makedirs(folder)
     return folder
 
 
-def create_shapley_schema(endpoint):
+def create_shapley_schema(
+    func: Callable, x: pandas.DataFrame, endpoint_name: str, profile_columns: List[str],
+):
     """Create shapley schema for endpoint"""
-    x, y = endpoint.get_input_and_output_for_profiling(full_x=True)
-    explainer = ShapExplainer(
-        func=endpoint.series_func, X=x, profile_columns=endpoint.profile_columns
-    )
-    folder = mkdir(endpoint=endpoint)
-    input_descriptions = [
-        create_description(x[col]) for col in endpoint.profile_columns
-    ]
+
+    explainer = ShapExplainer(func=func, x=x, profile_columns=profile_columns)
+    folder = mkdir(endpoint_name=endpoint_name)
+
+    input_descriptions = [create_description(x[col]) for col in profile_columns]
     logging.info("Shapley - Creating schema")
     fname = "schema.json"
     fpath = os.path.join(folder, fname)
-    data = create_explainer_schema(endpoint, explainer, input_descriptions)
+    example = x.head(1)
+    data = create_explainer_schema(example, explainer, input_descriptions,)
     with open(fpath, "w") as f:
         json.dump(jsonable_encoder(data), f)
 
 
-def create_explainer_schema(endpoint, explainer, input_descriptions):
+def create_explainer_schema(
+    explainer_schema_example: pandas.DataFrame,
+    explainer: ShapExplainer,
+    input_descriptions: List[Dict],
+) -> Dict:
     """Create schema for explainer input"""
-    schema_example = endpoint.explain_input_schema.pydantic.schema()["example"]
-    x = endpoint.explain_input_schema.to_pandas(schema_example)
 
-    pred = explainer.func(x)
-    baseline, explanation = explainer.explain(x)
+    pred = explainer.func(explainer_schema_example)
+    baseline, explanation = explainer.explain(explainer_schema_example)
 
     example = {
-        "inputs": schema_example,
+        "inputs": df_to_dict(explainer_schema_example),  # schema_example,
         "explanations": df_to_dict(explanation),
         "prediction": list(pred),
         "baseline": list(baseline),
@@ -58,12 +62,17 @@ def create_explainer_schema(endpoint, explainer, input_descriptions):
     return schema
 
 
-def create_accuracy(endpoint):
+def create_accuracy(
+    func: Callable,
+    x: pandas.DataFrame,
+    y: pandas.Series,
+    endpoint_name: str,
+    profile_columns: List[str],
+    kind: str,
+) -> None:
     """Create accuracy profile for endpoint"""
-    x, y = endpoint.get_input_and_output_for_profiling(full_x=True)
-    func = endpoint.series_func
-    kind = endpoint.KIND.value
-    folder = mkdir(endpoint=endpoint, spec_path="accuracy")
+
+    folder = mkdir(endpoint_name=endpoint_name, spec_path="accuracy")
 
     logging.info("Accuracy - Creating calibration plot")
     fname = "calibration.json"
@@ -81,35 +90,43 @@ def create_accuracy(endpoint):
     logging.info("Accuracy - Finding largest errors")
     fname = "errors.json"
     fpath = os.path.join(folder, fname)
-    errors_table = largest_errors(func, x, y, endpoint.profile_columns)
+    errors_table = largest_errors(func, x, y, profile_columns)
     with open(fpath, "w") as f:
         f.write(errors_table)
 
 
-def create_dependence(endpoint):
+def create_dependence(
+    func: Callable, x: pandas.DataFrame, endpoint_name: str, profile_columns: List[str],
+) -> None:
     """Create partial dependence graphs for all variables"""
-    x, y = endpoint.get_input_and_output_for_profiling(full_x=True, reset_index=True)
-    func = endpoint.series_func
-    folder = mkdir(endpoint=endpoint, spec_path="anatomy/partialdep")
 
-    for var in endpoint.profile_columns:
+    x = x.reset_index(drop=True)
+    folder = mkdir(endpoint_name=endpoint_name, spec_path="anatomy/partialdep")
+
+    for var in profile_columns:
         logging.info(f"Explanations - Creating partial dependence for {var}")
         fname = var + ".json"
         fpath = os.path.join(folder, fname)
         try:
-            chart = partialdep(func, x, y, var)
+            chart = partialdep(func=func, x=x, var=var)
             chart.save(fpath, format="json")
         except AttributeError:
             logging.warning(f"Could not generate valid chart for {var}")
 
 
-def create_expectations(endpoint):
+def create_expectations(
+    func: Callable,
+    x: pandas.DataFrame,
+    y: pandas.Series,
+    endpoint_name: str,
+    profile_columns: List[str],
+) -> None:
     """Create conditional expectations graphs for all variables"""
-    x, y = endpoint.get_input_and_output_for_profiling(full_x=True, reset_index=True)
-    func = endpoint.series_func
-    folder = mkdir(endpoint=endpoint, spec_path="anatomy/condexp")
 
-    for var in endpoint.profile_columns:
+    x, y = x.reset_index(drop=True), y.reset_index(drop=True)
+    folder = mkdir(endpoint_name=endpoint_name, spec_path="anatomy/condexp")
+
+    for var in profile_columns:
         logging.info(f"Explanations - Creating conditional expectations for {var}")
         fname = var + ".json"
         fpath = os.path.join(folder, fname)
@@ -124,21 +141,25 @@ def create_expectations(endpoint):
             logging.warning(f"Could not generate valid chart for {var}: {repr(e)}")
 
 
-def create_importance(endpoint):
-    """Create variable importance graphs"""
-    x, y = endpoint.get_input_and_output_for_profiling(full_x=True)
-    func = endpoint.series_func
+def create_importance(
+    func: Callable,
+    x: pandas.DataFrame,
+    y: pandas.Series,
+    endpoint_name: str,
+    profile_columns: List[str],
+    kind: str,
+) -> None:
 
     logging.info("Explanations - Calculating variable importance")
-    if endpoint.KIND.value == "regression":
-        chart, varlist = varimp(func, x, y, endpoint.profile_columns, metric="Rmse")
-    elif endpoint.KIND.value == "binary":
-        chart, varlist = varimp(func, x, y, endpoint.profile_columns, metric="AUC")
+    if kind == "regression":
+        chart, varlist = varimp(func, x, y, profile_columns, metric="Rmse")
+    elif kind == "binary":
+        chart, varlist = varimp(func, x, y, profile_columns, metric="AUC")
     else:
-        raise NotImplementedError("Unknown endpoint kind:" + endpoint.KIND.value)
+        raise NotImplementedError("Unknown endpoint kind:" + kind)
 
     # Save to disk
-    folder = mkdir(endpoint=endpoint, spec_path="anatomy")
+    folder = mkdir(endpoint_name=endpoint_name, spec_path="anatomy")
 
     fname = "varimp.json"
     fpath = os.path.join(folder, fname)
@@ -150,20 +171,18 @@ def create_importance(endpoint):
         json.dump(varlist, f)
 
 
-def create_summary(endpoint, explain_only=False):
-    endpoint_name = endpoint.series_func.__name__
+def create_summary(
+    endpoint_name: str, input_names: List[str], output_names: str, kind: str
+) -> None:
+
     logging.info(f"Summary - creating endpoint summary for endpoint: {endpoint_name}")
-    if explain_only:
-        endpoint_input_names = endpoint.explain_input_names
-    else:
-        endpoint_input_names = endpoint.input_names
     as_json = {
         "name": endpoint_name,
-        "kind": endpoint.KIND.value,
-        "inputs": endpoint_input_names,
-        "output": endpoint.output_names,
+        "kind": kind,
+        "inputs": input_names,
+        "output": output_names,
     }
     # Save to disk
-    folder = mkdir(endpoint=endpoint)
+    folder = mkdir(endpoint_name=endpoint_name)
     with open(os.path.join(folder, "summary.json"), "w") as summary:
         json.dump(as_json, summary)
