@@ -1,3 +1,5 @@
+from typing import Callable
+
 import altair as alt
 import numpy as np
 import pandas as pd
@@ -12,31 +14,39 @@ from pandas.api.types import (
 from profiling.utils import vega_sanitize
 
 
-def condexp(func, X, y, var):
+def condexp(
+    func: Callable[[pd.DataFrame], pd.Series], x: pd.DataFrame, y: pd.Series, var: str
+):
     """Plot conditional expectations"""
-    if is_categorical_dtype(X[var]):
-        return condexp_cat(func, X, y, var)
-    elif is_bool_dtype(X[var]):
-        return condexp_cat(func, X, y, var)
-    elif is_object_dtype(X[var]):
-        return condexp_cat(func, X, y, var)
-    elif is_numeric_dtype(X[var]):
-        return condexp_num(func, X, y, var)
-    elif is_datetime64_any_dtype(X[var]):
-        return condexp_datetime(func, X, y, var)
+    if is_categorical_dtype(x[var]):
+        return condexp_cat(func, x, y, var)
+    elif is_bool_dtype(x[var]):
+        return condexp_cat(func, x, y, var)
+    elif is_object_dtype(x[var]):
+        return condexp_cat(func, x, y, var)
+    elif is_numeric_dtype(x[var]):
+        return condexp_num(func, x, y, var)
+    elif is_datetime64_any_dtype(x[var]):
+        return condexp_datetime(func, x, y, var)
     else:
         pass
 
 
-def condexp_num(func, X, y, var, n_cut=10):
+def condexp_num(
+    func: Callable[[pd.DataFrame], pd.Series],
+    x: pd.DataFrame,
+    y: pd.Series,
+    var: str,
+    n_cut: int = 10,
+) -> alt.Chart:
     """Conditional expectations plot for numerical variables"""
 
-    non_missing = ~X[var].isna()
-    X = X[non_missing]
+    non_missing = ~x[var].isna()
+    x = x[non_missing]
     y = y[non_missing]
-    pred = func(X).to_numpy()
+    pred = func(x).to_numpy()
 
-    df = X.assign(pred=pred, y=y)
+    df = x.assign(pred=pred, y=y)
     if df[var].nunique() > n_cut:
         groupvar = df[var] + 1e-6 * np.random.uniform(size=len(df))
         df["groups"] = pd.qcut(groupvar, 10)
@@ -86,10 +96,16 @@ def flatten_index(df):
     return df
 
 
-def condexp_cat(func, X, y, var, n_max=25):
+def condexp_cat(
+    func: Callable[[pd.DataFrame], pd.Series],
+    x: pd.DataFrame,
+    y: pd.Series,
+    var: str,
+    n_max: int = 25,
+) -> alt.Chart:
     """Conditional expectations plot for categorical variables"""
-    pred = func(X)
-    df = X.assign(pred=pred, y=y).astype({var: "category"})
+    pred = func(x)
+    df = x.assign(pred=pred, y=y).astype({var: "category"})
 
     df_agg = (
         df.groupby(var, as_index=False, observed=True)
