@@ -1,4 +1,7 @@
+from typing import Any, Dict, List
+
 import numpy as np
+import pandas
 from pandas.api.types import (
     is_bool_dtype,
     is_categorical_dtype,
@@ -51,7 +54,7 @@ def df_to_dict(df):
     return dataset
 
 
-def create_description(series, n_options=100):
+def create_description(series, n_options=100) -> Dict:
     """Create an input description for a series for use in dropdowns
 
     Parameters
@@ -113,3 +116,12 @@ def vega_sanitize(var, datatype=None):
     if datatype:
         var = var + ":" + datatype
     return var
+
+
+def input_schema_to_pandas(value: Any, names: List[str]) -> pandas.DataFrame:
+    print(names, value)
+    if isinstance(value, pandas.DataFrame):
+        value.columns = names
+        return value
+    else:
+        return pandas.DataFrame(value, columns=names)
